<?php

// =============================================================================
// Synchi
// 
// Released under the GNU General Public Licence v2
// http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
//
// CodeMirror library is released under a MIT-style license
// http://codemirror.net/LICENSE
// 
// Please refer all questions/requests to: mdjekic@gmail.com
//
// This is an add-on for WordPress
// http://wordpress.org/
// =============================================================================

// =============================================================================
// This piece of software is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.
// =============================================================================

/*
  Plugin Name: Synchi
  Description: A very simple plugin that empowers you with code syntax highlighting within WP plugin and themes editor. Plugin is based on <a href="http://codemirror.net/">CodeMirror</a> library.
  Version: 2.2
  Author: Miloš Đekić
  Author URI: http://www.linkedin.com/in/mdjekic
 */

// synchi version
define("SYNCHI",'2.2');

// define paths
if(!defined('WP_PLUGIN_URL')) define('WP_PLUGIN_URL', WP_CONTENT_URL. '/plugins');
if(!defined('WP_PLUGIN_DIR')) define('WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins');
if(!defined('WP_ADMIN_URL')) define('WP_ADMIN_URL', get_bloginfo('wpurl') . '/wp-admin');

// define settings page unique name
define("SYNCHI_SETTINGS_PAGE",'synchi-settings');

// define themes
$synchi_themes = array('default','ambiance','blackboard','cobalt','eclipse','elegant','erlang-dark','monokai','neat','night','rubyblue','xq-dark');

/**
 * Request handler
 * 
 * @global $synchi_themes
 */
function synchi_request_handler() {
    global $synchi_themes;
    if(empty($_REQUEST['synchi_action'])) return;
    switch ($_REQUEST['synchi_action']) {
        case 'update_settings':
            if(!isset($_POST['synchi_option_theme'])) return;
            $theme = $_POST['synchi_option_theme'];
            if(!isset($theme) || empty($theme) || !in_array($theme, $synchi_themes)) $theme = 'default';
            update_option ('synchi_option_theme', $theme);
            header('Location: '.WP_ADMIN_URL.'/options-general.php?page='.SYNCHI_SETTINGS_PAGE.'&updated=true');
            die;
    }
}

/**
 * Initializes synchi plugin by adding JavaScript 
 * and CSS file includes to admin head
 * 
 * @global $synchi_themes
 */
function synchi_init() {
    global $synchi_themes;
    $theme = get_option('synchi_option_theme');
    if(!isset($theme) || empty($theme) || !in_array($theme, $synchi_themes)) $theme = 'default';
    include(WP_PLUGIN_DIR . '/synchi/head.php'); 
}

/**
 * Adds a menu item for synchi settings
 */
function synchi_menu() {
    add_submenu_page(
        'options-general.php', // parent
        'Synchi Theming', // page title
        'Synchi', // menu item title
        'administrator', // permission
        SYNCHI_SETTINGS_PAGE, // unique page name
        'synchi_settings' // rendering function
    );
}

/**
 * Renders settings HTML
 * 
 * @global $synchi_themes
 */
function synchi_settings() {
    global $synchi_themes;
    $theme = get_option('synchi_option_theme');
    if(!in_array($theme, $synchi_themes)) $theme = 'default';
    include(WP_PLUGIN_DIR . '/synchi/settings.php'); 
}

// register request handler handle
add_action('init', 'synchi_request_handler', 9999);

// register action handles
add_action('admin_head','synchi_init');

// register options
add_option('synchi_option_theme', 'default');

// register menu item
add_action('admin_menu', 'synchi_menu');